import urlparse
import requests

from django.core.urlresolvers import reverse
from django.db import models
from django.utils.translation import ugettext_lazy as _

from passerelle.base.models import BaseResource


class MontpellierSig(BaseResource):
    service_url = models.CharField(max_length=128, blank=False,
            verbose_name=_('Service URL'),
            help_text=_('SIG Web Service URL'))
    verify_cert = models.BooleanField(default=True,
            verbose_name=_('Check HTTPS Certificate validity'))
    username = models.CharField(max_length=128, blank=True,
            verbose_name=_('Username'))
    password = models.CharField(max_length=128, blank=True,
            verbose_name=_('Password'))
    keystore = models.FileField(upload_to='monpellier_sig', null=True,
            blank=True,
            verbose_name=_('Keystore'),
            help_text=_('Certificate and private key in PEM format'))

    category = _('Business Process Connectors')

    class Meta:
        verbose_name = _('Montpellier SIG Web Service')

    def get_absolute_url(self):
        return reverse('montpellier-sig-view', kwargs={'slug': self.slug})

    def sig_request(self, endpoint, **kwargs):
        if self.keystore:
            kwargs['cert'] = (self.keystore.path, self.keystore.path)
        if not self.verify_cert:
            kwargs['verify'] = False
        if self.username:
            kwargs['auth'] = (self.username, self.password)
        return requests.get(self.service_url + '/adresse/rest/' + endpoint, **kwargs).json()

    @classmethod
    def get_add_url(cls):
        return reverse('montpellier-sig-add')

    @classmethod
    def get_verbose_name(cls):
        return cls._meta.verbose_name

    @classmethod
    def get_icon_class(cls):
        return 'gis'
