import json

from django.test import TestCase
from django.test.client import Client

from django.core.urlresolvers import reverse

from passerelle_montpellier_sig.models import MontpellierSig
from passerelle_montpellier_sig.views import prefix_cleanup, split_street


class PrefixCleanupTestCase(TestCase):

    def test_prefix_alle(self):
        self.assertEqual(prefix_cleanup('ALL DE LA PAIX'), 'ALLEE DE LA PAIX')

    def test_prefix_viaduc(self):
        self.assertEqual(prefix_cleanup('VIAD ALPHONSE LOUBAT'), 'VIADUC ALPHONSE LOUBAT')

    def test_prefix_voie(self):
        self.assertEqual(prefix_cleanup('VOI DOMITIENNE'), 'VOIE DOMITIENNE')

    def test_prefix_square(self):
        self.assertEqual(prefix_cleanup('SQ SAINT FIACRE'), 'SQUARE SAINT FIACRE')

    def test_prefix_terasse(self):
        self.assertEqual(prefix_cleanup('TSSE TERRASSE DES ALLEES DU BOIS'), 'TERRASSE DES ALLEES DU BOIS')

    def test_prefix_route(self):
        self.assertEqual(prefix_cleanup('RTE DE LODEVE'), 'ROUTE DE LODEVE')

    def test_prefix_rondpoint(self):
        self.assertEqual(prefix_cleanup('RPT RENE CHAR'), 'ROND-POINT RENE CHAR')

    def test_prefix_rue(self):
        self.assertEqual(prefix_cleanup('R WILLIAM ET CATHERINE BOOTH'), 'RUE WILLIAM ET CATHERINE BOOTH')

    def test_prefix_place(self):
        self.assertEqual(prefix_cleanup('PL PABLO PICASSO'), 'PLACE PABLO PICASSO')

    def test_prefix_passage(self):
        self.assertEqual(prefix_cleanup('PAS HANS CHRISTIAN ANDERSEN'), 'PASSAGE HANS CHRISTIAN ANDERSEN')

    def test_prefix_jardin(self):
        self.assertEqual(prefix_cleanup('JARD LES JARDINS DU CORUM'), 'JARDIN LES JARDINS DU CORUM')

    def test_prefix_impasse(self):
        self.assertEqual(prefix_cleanup('IMP VILLEHARDOUIN'), 'IMPASSE VILLEHARDOUIN')

    def test_prefix_esplanade(self):
        self.assertEqual(prefix_cleanup('ESP DE LA MUSIQUE'), 'ESPLANADE DE LA MUSIQUE')

    def test_prefix_chausse(self):
        self.assertEqual(prefix_cleanup('CHE DES GRENADIERS'), 'CHAUSSEE DES GRENADIERS')

    def test_prefix_boulevard(self):
        self.assertEqual(prefix_cleanup('BD RENOUVIER'), 'BOULEVARD RENOUVIER')

    def test_prefix_avenue(self):
        self.assertEqual(prefix_cleanup('AV RAYMOND DUGRAND'), 'AVENUE RAYMOND DUGRAND')


class ReverseGeolocTest(TestCase):

    def test_get_rue(self):
        self.assertEqual(split_street('17 bis R WILLIAM ET CATHERINE BOOTH'), ('17 bis', 'RUE WILLIAM ET CATHERINE BOOTH'))

    def test_split_impasse(self):
        self.assertEqual(split_street(' 5 IMP VILLEHARDOUIN'), ('5', 'IMPASSE VILLEHARDOUIN'))

    def test_split_avenue(self):
        self.assertEqual(split_street('42 AV RAYMOND DUGRAND '), ('42', 'AVENUE RAYMOND DUGRAND'))
